DaqConfig

Struct DaqConfig 

pub struct DaqConfig {
    pub api: DaqApiDescriptor,
    pub device_name: String,
    pub inchannel_config: Vec<DaqChannel>,
    pub outchannel_config: Vec<DaqChannel>,
    pub dtype: DataType,
    pub digitalHighPassCutOn: Flt,
    pub sampleRateIndex: usize,
    pub framesPerBlockIndex: usize,
    pub monitorOutput: bool,
}
Configuration of a device.

Fields

api: DaqApiDescriptor

The API

device_name: String

Device name. Should match when starting a stream

inchannel_config: Vec<DaqChannel>

Configuration of the input channels

outchannel_config: Vec<DaqChannel>

Configuration of the output channels

dtype: DataType

The data type to use

digitalHighPassCutOn: Flt

Whether to apply a digital high pass on the input. <= 0 means disabled. > 0 means, the value specifies the cut-on frequency for the first order high pass filter.

sampleRateIndex: usize

The index to use in the list of possible sample rates

framesPerBlockIndex: usize

The index to use in the list of possible frames per block

monitorOutput: bool

Used when output channels should be monitored, i.e. reverse-looped back as input channels.

Implementations

Source

impl DaqConfig

pub fn numberEnabledInChannels(&self) -> usize

Returns the total number of channels that appear in a running input stream.

pub fn numberEnabledOutChannels(&self) -> usize

Returns the total number of channels that appear in a running output stream.

pub fn sampleRate(&self, dev: &DeviceInfo) -> Flt

Provide samplerate, based on device and specified sample rate index

pub fn framesPerBlock(&self, dev: &DeviceInfo) -> usize

Provide samplerate, based on device and specified sample rate index

pub fn enabledInChannels(&self) -> Vec<DaqChannel>

Returns vec of channel configuration for enabled input channels only

pub fn enabledInchannelsList(&self) -> Vec<usize>

Returns a list of enabled input channel numbers as indices in the list of all input channels (enabled and not)

pub fn enabledOutChannels(&self) -> Vec<DaqChannel>

Returns vec of channel configuration for enabled output channels only

pub fn highestEnabledInChannel(&self) -> Option<usize>

Returns the channel number of the highest enabled input channel, if any.

pub fn highestEnabledOutChannel(&self) -> Option<usize>

Returns the channel number of the highest enabled output channel, if any.

pub fn setAllOutputEnabled(&mut self, enabled: bool)

Change state of all output channels, enables them all, or disables them all.

Source

impl DaqConfig

pub fn newFromDeviceInfo(devinfo: &DeviceInfo) -> DaqConfig

Creates a new default device configuration for a given device as specified with the DeviceInfo descriptor.

pub fn serialize_TOML(&self, writer: &mut dyn Write) -> Result<()>

Serialize DaqConfig object to TOML.

Args

  • writer: Output writer, can be file or string, or anything that is std::io::Write
pub fn deserialize_TOML<T>(reader: &mut T) -> Result<DaqConfig>
where T: Read,

Deserialize structure from TOML data

Args
  • reader: implements the Read trait, from which we read the data.
pub fn deserialize_TOML_str(st: &str) -> Result<DaqConfig>

Deserialize from TOML string

Args
  • st: string containing TOML data.
pub fn serialize_TOML_file(&self, file: &PathBuf) -> Result<()>

Write this configuration to a TOML file.

Args

  • file: Name of file to write to