pub struct Recording { /* private fields */ }Expand description
This struct lets a recording run on a stream, waits till the first data arrives and records for a given period of time. Usage:
use lasprs::daq::{RecordSettings, StreamMgr, Recording};
use std::time::Duration;
fn main() -> anyhow::Result<()> {
let mut smgr = StreamMgr::new();
smgr.startDefaultInputStream()?;
// Create record settings
let settings = RecordSettings::new(
"test.h5",
Duration::from_millis(100),
None,
);
let rec = Recording::new(settings, &mut smgr)?;
Ok(())
}Implementations