pub enum FilterSpec {
Bandpass {
fl: Flt,
fu: Flt,
order: u32,
},
Lowpass {
fc: Flt,
order: u32,
},
Highpass {
fc: Flt,
order: u32,
},
}Expand description
Specification of a filter for a certain type.
The order corresponds to the rolloff in dB/decade. order=1 means 20 dB/dec, order=2 40 dB/dec and so on. For a bandpass filter, the order also corresponds to the roll-off and roll-on of the filter. For this case, the order is not ‘shared’ between the highpass and lowpass part.
Variants
Bandpass
Bandpass filter. Cuton frequency fl in [Hz]. Cutoff frequency fu
in [Hz]. Typically implemented as a highpass combined with a lowpass.
Fields
Lowpass
Lowpass filter. Cutoff frequency fc in [Hz].
Highpass
Highpass filter. Cuton frequency fc in [Hz].