ZPKModel

Struct ZPKModel 

pub struct ZPKModel { /* private fields */ }
Analog zero-pole-gain model for real input to real output. Provides methods to generate analog filters of standard type, i.e. bandpass, lowpass and highpass. These can subsequentially be used to generate a digital filter.

Example: Create a digital second order Butterworth bandpass filter

use lasprs::filter::{FilterSpec, ZPKModel};
let fs = 48000.;

let butter = ZPKModel::butter(FilterSpec::Bandpass{fl: 10., fu: 100., order: 2});
let mut filt = butter.bilinear(fs);

It has a transfer function that can be described as a rational function of the form:

         Π_i (s-z_i)
H(s) = k ------------
         Π_i (s-p_i)

where Π denotes the product of a series, z_i are the zeros, and p_i are the poles. In order to have real output for a real input, the zeros and poles should either be real, or come in complex conjugate pairs. This is enforced by the way the poles and zero’s are internally stored.

Implementations

Source

impl ZPKModel

pub fn new<T, U>(zeros: T, poles: U, k: Flt) -> ZPKModel
where T: Into<Vec<PoleOrZero>>, U: Into<Vec<PoleOrZero>>,

Creata a new ZPK model, with give list of poles and zeros, and gain

Args
  • zeros - list like struct of zeros. Can be a Vec<ZeroOrPole> or an &[ZeroOrPole].
  • poles - list like struct of poles. Can be a Vec<ZeroOrPole> or an &[ZeroOrPole].
  • k - linear gain.
pub fn setWarpFreq(self, fcrit: Flt) -> ZPKModel

Set critical frequency in filter, used for bilinear transform.

Args
  • fcrit - New critical frequency in [Hz].
pub fn setGainAt(self, freq: Flt, required_gain: Flt) -> ZPKModel

Change the gain value such that it matches val at frequency freq. Does not change the phase at the given frequency.

pub fn butter(spec: FilterSpec) -> ZPKModel

Create a Butterworth filter according to a certain specification in spec.

Panics
  • If specified order == 0
  • If order is larger than [BUTTER_MAX_ORDER].
  • If for a bandpass filter fl>=fu.
  • If fl, or fu < 0.
pub fn bilinear(&self, fs: Flt) -> SeriesBiquad

Apply bilinear transform to obtain series biquads from this ZPK model. Pre-warping is taken into account, based on settings stored in ZPKModel. Using ZPKModel::setWarpFreq, this can be overridden.

Args
  • fs - Sampling frequency [Hz]
pub fn freqWeightingFilter(wt: FreqWeighting) -> ZPKModel

Create analog filter prototype for a frequency weighting as used in Sound Level Meters.

Args
  • wt - [FreqWeighting] to use. i.e. A-weighting.
Examples
Get part of pulse response of digital A-filter at 48 kHz
use lasprs::filter::{ZPKModel, FreqWeighting, Filter};

// Sampling frequency in Hz
let fs = 48000.;

let mut afilter = ZPKModel::freqWeightingFilter(FreqWeighting::A).bilinear(fs);
let mut data = [0.; 1000];
data[0] = 1.0;
let out = afilter.filter(&data);