pub enum ApsMode {
AllAveraging {},
ExponentialWeighting {
tau: Flt,
},
Spectrogram {},
}Expand description
The ‘mode’ used in computing averaged power spectra. When providing data in blocks to the [AvPowerSpectra] the resulting ‘current estimate’ responds differently, depending on the model.
Variants
AllAveraging
Averaged over all data provided. New averages can be created by calling
AvPowerSpectra::reset()
ExponentialWeighting
In this mode, the AvPowerSpectra works a bit like a sound level meter,
where new data is weighted with old data, and old data exponentially
backs off. This mode only makes sense when tau >> nfft/fs
Fields
Spectrogram
Spectrogram mode. Only returns the latest estimate(s).