pub struct DaqConfig {
pub api: DaqApiDescriptor,
pub device_name: String,
pub inchannel_config: Vec<DaqChannel>,
pub outchannel_config: Vec<DaqChannel>,
pub dtype: DataType,
pub digitalHighPassCutOn: Flt,
pub sampleRateIndex: usize,
pub framesPerBlockIndex: usize,
pub monitorOutput: bool,
}Expand description
Configuration of a device.
Fields
api: DaqApiDescriptorThe API
device_name: StringDevice name. Should match when starting a stream
inchannel_config: Vec<DaqChannel>Configuration of the input channels
outchannel_config: Vec<DaqChannel>Configuration of the output channels
dtype: DataTypeThe data type to use
digitalHighPassCutOn: FltWhether to apply a digital high pass on the input. <= 0 means disabled. > 0 means, the value specifies the cut-on frequency for the first order high pass filter.
sampleRateIndex: usizeThe index to use in the list of possible sample rates
framesPerBlockIndex: usizeThe index to use in the list of possible frames per block
monitorOutput: boolUsed when output channels should be monitored, i.e. reverse-looped back as input channels.
Implementations
Sourceimpl DaqConfig
impl DaqConfig
Sourcepub fn numberEnabledInChannels(&self) -> usize
pub fn numberEnabledInChannels(&self) -> usize
Returns the total number of channels that appear in a running input stream.
Sourcepub fn numberEnabledOutChannels(&self) -> usize
pub fn numberEnabledOutChannels(&self) -> usize
Returns the total number of channels that appear in a running output stream.
Sourcepub fn sampleRate(&self, dev: &DeviceInfo) -> Flt
pub fn sampleRate(&self, dev: &DeviceInfo) -> Flt
Provide samplerate, based on device and specified sample rate index
Sourcepub fn framesPerBlock(&self, dev: &DeviceInfo) -> usize
pub fn framesPerBlock(&self, dev: &DeviceInfo) -> usize
Provide samplerate, based on device and specified sample rate index
Sourcepub fn enabledInChannels(&self) -> Vec<DaqChannel>
pub fn enabledInChannels(&self) -> Vec<DaqChannel>
Returns vec of channel configuration for enabled input channels only
Sourcepub fn enabledInchannelsList(&self) -> Vec<usize>
pub fn enabledInchannelsList(&self) -> Vec<usize>
Returns a list of enabled input channel numbers as indices in the list of all input channels (enabled and not)
Sourcepub fn enabledOutChannels(&self) -> Vec<DaqChannel>
pub fn enabledOutChannels(&self) -> Vec<DaqChannel>
Returns vec of channel configuration for enabled output channels only
Sourcepub fn highestEnabledInChannel(&self) -> Option<usize>
pub fn highestEnabledInChannel(&self) -> Option<usize>
Returns the channel number of the highest enabled input channel, if any.
Sourcepub fn highestEnabledOutChannel(&self) -> Option<usize>
pub fn highestEnabledOutChannel(&self) -> Option<usize>
Returns the channel number of the highest enabled output channel, if any.
Sourcepub fn setAllOutputEnabled(&mut self, enabled: bool)
pub fn setAllOutputEnabled(&mut self, enabled: bool)
Change state of all output channels, enables them all, or disables them all.
Sourceimpl DaqConfig
impl DaqConfig
Sourcepub fn newFromDeviceInfo(devinfo: &DeviceInfo) -> DaqConfig
pub fn newFromDeviceInfo(devinfo: &DeviceInfo) -> DaqConfig
Creates a new default device configuration for a given device as specified with the DeviceInfo descriptor.
Sourcepub fn serialize_TOML(&self, writer: &mut dyn Write) -> Result<()>
pub fn serialize_TOML(&self, writer: &mut dyn Write) -> Result<()>
Serialize DaqConfig object to TOML.
Args
- writer: Output writer, can be file or string, or anything that is std::io::Write
Sourcepub fn deserialize_TOML<T>(reader: &mut T) -> Result<DaqConfig>where
T: Read,
pub fn deserialize_TOML<T>(reader: &mut T) -> Result<DaqConfig>where
T: Read,
Deserialize structure from TOML data
Args
- reader: implements the Read trait, from which we read the data.
Sourcepub fn deserialize_TOML_str(st: &str) -> Result<DaqConfig>
pub fn deserialize_TOML_str(st: &str) -> Result<DaqConfig>
Sourcepub fn serialize_TOML_file(&self, file: &PathBuf) -> Result<()>
pub fn serialize_TOML_file(&self, file: &PathBuf) -> Result<()>
Write this configuration to a TOML file.
Args
- file: Name of file to write to